@@ -235,7 +235,7 @@ func parseServerStatsPacket(p chrony.ResponsePacket) (chrony.ReplyServerStats4,
 	return serverStats, nil
 }
 
-func (e Exporter) getServerstatsMetrics(logger *slog.Logger, ch chan<- prometheus.Metric, client chrony.Client) error {
+func (e Exporter) getServerstatsMetrics(logger *slog.Logger, ch chan<- prometheus.Metric, client *chrony.Client) error {
 	packet, err := client.Communicate(chrony.NewServerStatsPacket())
 	if err != nil {
 		return err
