@@ -160,7 +160,7 @@ var (
 	}
 )
 
-func (e Exporter) getSourcesMetrics(logger *slog.Logger, ch chan<- prometheus.Metric, client chrony.Client, collectNtpdata bool) error {
+func (e Exporter) getSourcesMetrics(logger *slog.Logger, ch chan<- prometheus.Metric, client *chrony.Client, collectNtpdata bool) error {
 	packet, err := client.Communicate(chrony.NewSourcesPacket())
 	if err != nil {
 		return err
@@ -188,11 +188,17 @@ func (e Exporter) getSourcesMetrics(logger *slog.Logger, ch chan<- prometheus.Me
 	}
 
 	for _, r := range results {
+		if r.IPAddr.Family == chrony.IPAddrID {
+			logger.Debug("Skipping unresolved IP address", "address", r.IPAddr.String())
+			continue
+		}
 		sourceAddress := r.IPAddr.String()
-		sourceName := e.dnsLookup(logger, r.IPAddr)
+		sourceName := e.dnsLookup(logger, r.IPAddr.ToNetIP())
 
-		if r.Mode == chrony.SourceModeRef && r.IPAddr.To4() != nil {
-			sourceName = chrony.RefidToString(binary.BigEndian.Uint32(r.IPAddr))
+		if r.Mode == chrony.SourceModeRef && r.IPAddr.ToNetIP().To4() != nil {
+			refid := chrony.RefidToString(binary.BigEndian.Uint32(r.IPAddr.ToNetIP().To4()))
+			sourceAddress = refid
+			sourceName = refid
 		}
 
 		// Compute the reachability from the Reachability bits.
@@ -208,7 +214,8 @@ func (e Exporter) getSourcesMetrics(logger *slog.Logger, ch chan<- prometheus.Me
 		ch <- sourcesStateInfo.mustNewConstMetric(1.0, sourceAddress, sourceName, r.State.String(), r.Mode.String())
 		ch <- sourcesStratum.mustNewConstMetric(float64(r.Stratum), sourceAddress, sourceName)
 
-		if collectNtpdata {
+		// Skip NTP data collection for reference clocks as they don't have NTP protocol data
+		if collectNtpdata && r.Mode != chrony.SourceModeRef {
 			ntpDataPacket, err := client.Communicate(chrony.NewNTPDataPacket(r.IPAddr))
 			if err != nil {
 				return fmt.Errorf("failed to get ntpdata response for: %s", r.IPAddr)
